@@ -2,23 +2,21 @@
 #define _RAR_RARCOMMON_
 
 #include "raros.hpp"
+#include "rartypes.hpp"
 #include "os.hpp"
 
 #ifdef RARDLL
 #include "dll.hpp"
 #endif
 
-#ifndef _WIN_CE
 #include "version.hpp"
-#endif
-#include "rartypes.hpp"
 #include "rardefs.hpp"
 #include "rarlang.hpp"
 #include "unicode.hpp"
 #include "errhnd.hpp"
+#include "secpassword.hpp"
 #include "array.hpp"
 #include "timefn.hpp"
-#include "secpassword.hpp"
 #include "sha1.hpp"
 #include "sha256.hpp"
 #include "blake2s.hpp"
@@ -31,8 +29,12 @@
 #include "pathfn.hpp"
 #include "strfn.hpp"
 #include "strlist.hpp"
+#ifdef _WIN_ALL
+#include "isnt.hpp"
+#endif
 #include "file.hpp"
 #include "crc.hpp"
+#include "ui.hpp"
 #include "filefn.hpp"
 #include "filestr.hpp"
 #include "find.hpp"
@@ -47,14 +49,10 @@
 #include "match.hpp"
 #include "cmddata.hpp"
 #include "filcreat.hpp"
-#ifndef GUI
 #include "consio.hpp"
-#endif
 #include "system.hpp"
-#ifdef _WIN_ALL
-#include "isnt.hpp"
-#endif
 #include "log.hpp"
+#include "rawint.hpp"
 #include "rawread.hpp"
 #include "encname.hpp"
 #include "resource.hpp"
@@ -79,11 +77,21 @@
 
 #include "rs.hpp"
 #include "rs16.hpp"
+
+
+
 #include "recvol.hpp"
 #include "volume.hpp"
 #include "smallfn.hpp"
 
 #include "global.hpp"
 
+#if 0
+#include "benchmark.hpp"
+#endif
+
+
+
+
 
 #endif
